@@ -23,7 +23,7 @@ our @EXPORT_OK = qw(
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-02-18'; # DATE
 our $DIST = 'WWW-PAUSE-Simple'; # DIST
-our $VERSION = '0.457'; # VERSION
+our $VERSION = '0.458'; # VERSION
 
 our %SPEC;
 my $access_log = Log::ger->get_logger(category => "_access");
@@ -246,7 +246,10 @@ sub _request {
             $tries++;
             my $delay = $strategy->failure;
             if ($delay < 0) {
-                log_warn("Got error %s (%s) from server when POST-ing to %s%s, giving up");
+                log_warn("Got error %s (%s) from server when POST-ing to %s%s, giving up",
+                         $resp->code, $resp->message,
+                         $url,
+                         $args{note} ? " ($args{note})" : "");
                 last;
             } else {
                 log_warn("Got error %s (%s) from server when POST-ing to %s%s, retrying (%d/%d) in %d second(s) ...",
@@ -1012,7 +1015,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.457 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2024-02-18.
+This document describes version 0.458 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2024-02-18.
 
 =head1 SYNOPSIS
 
